# pseudo-ecg

Library to compute pseudo ECG from bidomain and monodomain simulations

- Source code: https://github.com/ComputationalPhysiology/pseudo-ecg
- Documentation: https://computationalphysiology.github.io/pseudo-ecg

## Install
You can install the library with pip
```
python3 -m pip install pseudo-ecg
```


## Getting started

TbW

## License
MIT

## Need help or having issues
Please submit an [issue](https://github.com/ComputationalPhysiology/pseudo-ecg/issues)
